@@ -1,5 +1,5 @@
 /*******************************************************************************
-* Copyright 2019-2023 Intel Corporation
+* Copyright 2019-2024 Intel Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
@@ -82,6 +82,21 @@
 /// DPC++ runtime
 #define DNNL_RUNTIME_DPCPP DNNL_RUNTIME_SYCL
 
+/// No vendor (corresponding runtime is disabled)
+#define DNNL_VENDOR_NONE 0u
+
+/// Intel vendor
+#define DNNL_VENDOR_INTEL 1u
+
+/// NVIDIA vendor
+#define DNNL_VENDOR_NVIDIA 2u
+
+/// AMD vendor
+#define DNNL_VENDOR_AMD 4u
+
+/// Generic vendor
+#define DNNL_VENDOR_GENERIC 8u
+
 /// @} dnnl_api_service
 
 // oneDNN CPU threading runtime
@@ -93,6 +108,9 @@
 // oneDNN GPU engine runtime
 #define DNNL_GPU_RUNTIME DNNL_RUNTIME_NONE
 
+// oneDNN GPU vendor
+#define DNNL_GPU_VENDOR DNNL_VENDOR_NONE
+
 // clang-format on
 
 #if defined(DNNL_CPU_RUNTIME) && defined(DNNL_GPU_RUNTIME)
@@ -136,6 +154,9 @@
 // When defined, SYCL HIP backend is used.
 /* #undef DNNL_SYCL_HIP */
 
+// When defined, SYCL Generic backend is used.
+/* #undef DNNL_SYCL_GENERIC */
+
 // When defined, stack checker is enabled.
 /* #undef DNNL_ENABLE_STACK_CHECKER */
 
@@ -145,12 +166,20 @@
 // When defined, experimental functionality for sparse domain is enabled.
 /* #undef DNNL_EXPERIMENTAL_SPARSE */
 
+// When defined, experimental functionality for ukernels is enabled.
+/* #undef DNNL_EXPERIMENTAL_UKERNEL */
+
 // When defined, graph component is enabled.
 #define ONEDNN_BUILD_GRAPH
 
 // When defined, experimental profiling capabilities are enabled.
 /* #undef DNNL_EXPERIMENTAL_PROFILING */
 
+// When defined, experimental logging capabilities are enabled.
+/* #undef DNNL_EXPERIMENTAL_LOGGING */
+// When defined, it disables GPU compute reference kernels.
+/* #undef DNNL_DISABLE_GPU_REF_KERNELS */
+
 // List of configurating build controls
 // Workload controls
 #define BUILD_TRAINING 1
@@ -163,6 +192,7 @@
 #define BUILD_CONVOLUTION 0
 #define BUILD_DECONVOLUTION 0
 #define BUILD_ELTWISE 0
+#define BUILD_GROUP_NORMALIZATION 0
 #define BUILD_INNER_PRODUCT 0
 #define BUILD_LAYER_NORMALIZATION 0
 #define BUILD_LRN 0
@@ -173,6 +203,7 @@
 #define BUILD_REORDER 0
 #define BUILD_RESAMPLING 0
 #define BUILD_RNN 0
+#define BUILD_SDPA 0
 #define BUILD_SHUFFLE 0
 #define BUILD_SOFTMAX 0
 #define BUILD_SUM 0
@@ -190,4 +221,12 @@
 #define BUILD_XEHP 0
 #define BUILD_XEHPG 0
 #define BUILD_XEHPC 0
+#define BUILD_XE2 0
+#define BUILD_XE3 0
+// GeMM kernels ISA controls
+#define BUILD_GEMM_KERNELS_ALL 1
+#define BUILD_GEMM_KERNELS_NONE 0
+#define BUILD_GEMM_SSE41 0
+#define BUILD_GEMM_AVX2 0
+#define BUILD_GEMM_AVX512 0
 #endif
